/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.gobblin.hive;

import com.google.common.util.concurrent.Striped;
import java.io.IOException;
import java.util.Properties;
import java.util.concurrent.locks.Lock;


/**
 * A lock factory that provide a get method for a HiveLockImpl for a specific object
 */
public class HiveLockFactory {
  protected Properties properties;
  private final Striped<Lock> locks = Striped.lazyWeakLock(Integer.MAX_VALUE);
  public HiveLockFactory(Properties _properties) {
    this.properties = _properties;

  }
  public HiveLockImpl get(String name) {

    return new HiveLockImpl<Lock>(locks.get(name)) {
      @Override
      public void lock() throws IOException {
        this.lock.lock();
      }

      @Override
      public void unlock() throws IOException {
        this.lock.unlock();
      }
    };
  }
}
